@@ -27,7 +27,8 @@ Plack::App::RDF::LinkedData - A Plack application for running RDF::LinkedData
 
 This module sets up a basic Plack application to use
 L<RDF::LinkedData> to serve Linked Data, while making sure it does
-follow best practices for doing so.
+follow best practices for doing so. See the README for quick start,
+the gory details are here.
 
 =head1 MAKE IT RUN
 
@@ -74,12 +75,14 @@ file C<rdf_linkeddata.json> that looks something like:
 	                 "resource_links": true
 	                }
                     },
+        "expires" : "A86400" ,
         "cors": {
                   "origins": "*"
                 },
         "void": {
                   "pagetitle": "VoID Description for my dataset"
-                }
+                },
+        "fragments" : { "fragments_path" : "/fragments" }
   }
 
 In your shell set
@@ -96,13 +99,30 @@ The C<endpoint>-part of the config sets up a SPARQL Endpoint. This requires
 the L<RDF::Endpoint> module, which is recommended by this module. To
 use it, it needs to have some config, but will use defaults.
 
-The last, C<cors>-part of the config enables Cross-Origin Resource
+It is also possible to set an C<expires> time. This needs
+L<Plack::Middleware::Expires> and uses Apache C<mod_expires> syntax,
+in the example above, it will set an expires header for all resources
+to expire after 1 day of access.
+
+The C<cors>-part of the config enables Cross-Origin Resource
 Sharing, which is a W3C Recommendation for relaxing security
 constraints to allow data to be shared across domains. In most cases,
 this is what you want when you are serving open data, but in some
 cases, notably intranets, this should be turned off by removing this
 part.
 
+The C<void>-part generates some statistics and a description of the
+dataset, using RDF::Generator::Void. It is strongly recommended to
+install and run that, but it can take some time to generate, so you
+may have to set the detail level.
+
+Finally, C<fragments> add support for Triple Pattern Fragments, a
+work-in-progress, It is a more lightweight but less powerful way to
+query RDF data than SPARQL. If you have this, it is recommended to
+have CORS enabled and required to have at least a minimal VoID setup.
+
+
+
 =head2 Details of the implementation
 
 This server is a minimal Plack-script that should be sufficient for
@@ -283,6 +303,7 @@ sub prepare_app {
 	$self->{linkeddata} = RDF::LinkedData->new(store => $config->{store},
 															 endpoint_config => $config->{endpoint},
 															 void_config => $config->{void},
+															 fragments_config => $config->{fragments},
 															 base_uri => $config->{base_uri}
 															);
 	$self->{linkeddata}->namespaces(URI::NamespaceMap->new($config->{namespaces})) if ($config->{namespaces});
@@ -302,6 +323,10 @@ sub call {
 		return [ 405, [ 'Content-type', 'text/plain' ], [ 'Method not allowed' ] ];
 	}
 
+	if (($uri->path eq '/.well-known/void') && ($ld->has_void)) {
+		return [ 302, [ 'Location', $ld->base_uri . '/' ], [ '' ] ];
+	}
+
 	if ($uri->as_iri =~ m!^(.+?)/?(page|data)$!) {
 		$uri = URI->new($1);
 		$ld->type($2);
@@ -320,7 +345,7 @@ Kjetil Kjernsmo, C<< <kjetilk@cpan.org> >>
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2010,2011,2012,2013,2014 Kjetil Kjernsmo
+Copyright 2010, 2011, 2012, 2013, 2014, 2015 Kjetil Kjernsmo
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
